==> badpy-1.5.tar.gz: badpy-1.5/README.md <==
# badpy (Created By Error)

badpy is a python package with modules required for hacking.

## Installation

Use the package manager pip3 to install badpy.

```bash
pip3 install badpy
# if module not working  try this : 
pip install badpy=1.5 --upgrade
```

## Usage

```python
dork(url,show) # dork module is finding websites admin panel
"""
show = True or False it means if show = True print brute force and outputs will be colorfully. Like [!][WARNING] will be yellow and [+] will be green... otherwise i mean if show=False these will just one output (the result). And noncolorfull. Even you can make result equal to string veriable. Look down for examples.
"""
locate(ip,cmd)
"""
ip = ip
cmd = command to get information about ip adress.
here is all commands :
countrycode : Country Code
country     : Country
region      : Region
city        : City
regionno    : RegionName
postal      : Postal Code (zip)
timezone    : Timezone
mobile      : Mobile
operator    : Operator (isp)
porxy       : Proxy
"""
```

### Google Dorking Module (1.3)
```python
from badpy import * # importing badpy module

# Option 1
dork("http://thesaderror.cf/",True) # with this module you can see brute force and output will be colorfull.
# Option 2
n = dork("http://thesaderror.cf/",False) # this is for make output simple. And you can make output equal to a veriable.
print(n)
```

### IP Information Gathering (1.3)
```python
from badpy import * # importing badpy module

print(locate("172.253.11.2","country"))
# for commands please look up
"""
here is all commands :
countrycode : Country Code
country     : Country
region      : Region
city        : City
regionno    : RegionName
postal      : Postal Code (zip)
timezone    : Timezone
mobile      : Mobile
operator    : Operator (isp)
porxy       : Proxy
"""
```
### Discord Spammer (1.4)
```python
from badpy import * # importing badpy module

dcspam('yourdiscordwebhookurl','messagetospam')
#this command will spam with webhook. It is Usefully! LOL.
```

## Contact : 
Github  : [TheSadError](https://github.com/TheSadError/)\
Gmail   : syntaxerrorses@gmail.com

# Log :
```
[1.3] Dork Module
[1.3] IP Information Gathering
[1.4] Discord Spammer
```
## License
[MIT](https://choosealicense.com/licenses/mit/)

# For Educational Purposes

==> badpy-1.6.tar.gz: badpy-1.6/README.md <==
# badpy (Created By Error)

badpy is a python package with modules required for hacking.

## Installation

Use the package manager pip3 to install badpy.

```bash
pip3 install badpy
# if module not working  try this : 
pip install badpy==1.6 --upgrade
```

## Usage

```python
dork(url,show) # dork module is finding websites admin panel
"""
show = True or False it means if show = True print brute force and outputs will be colorfully. Like [!][WARNING] will be yellow and [+] will be green... otherwise i mean if show=False these will just one output (the result). And noncolorfull. Even you can make result equal to string veriable. Look down for examples.
"""
locate(ip,cmd)
"""
ip = ip
cmd = command to get information about ip adress.
here is all commands :
countrycode : Country Code
country     : Country
region      : Region
city        : City
regionno    : RegionName
postal      : Postal Code (zip)
timezone    : Timezone
mobile      : Mobile
operator    : Operator (isp)
porxy       : Proxy
"""
```

### Google Dorking Module (1.3)
```python
from badpy import * # importing badpy module

# Option 1
dork("http://thesaderror.cf/",True) # with this module you can see brute force and output will be colorfull.
# Option 2
n = dork("http://thesaderror.cf/",False) # this is for make output simple. And you can make output equal to a veriable.
print(n)
```

### IP Information Gathering (1.3)
```python
from badpy import * # importing badpy module

print(locate("172.253.11.2","country"))
# for commands please look up
"""
here is all commands :
countrycode : Country Code
country     : Country
region      : Region
city        : City
regionno    : RegionName
postal      : Postal Code (zip)
timezone    : Timezone
mobile      : Mobile
operator    : Operator (isp)
porxy       : Proxy
"""
```
### Discord Spammer (1.4)
```python
from badpy import * # importing badpy module

dcspam('yourdiscordwebhookurl','messagetospam')
#this command will spam with webhook. It is Usefully! LOL.
```

## Contact : 
Github  : [TheSadError](https://github.com/TheSadError/)\
Gmail   : syntaxerrorses@gmail.com

# Log :
```
[1.3] Dork Module
[1.3] IP Information Gathering
[1.4] Discord Spammer
```
## License
[MIT](https://choosealicense.com/licenses/mit/)

# For Educational Purposes
